@@ -25,6 +25,7 @@ from langtrace_python_sdk.utils.llm import (
     get_llm_url,
     is_streaming,
     set_event_completion,
+    set_event_completion_chunk,
     set_usage_attributes,
 )
 from opentelemetry.trace import SpanKind
@@ -119,10 +120,7 @@ def messages_create(original_method, version, tracer):
                 # Assuming span.add_event is part of a larger logging or event system
                 # Add event for each chunk of content
                 if content:
-                    span.add_event(
-                        Event.STREAM_OUTPUT.value,
-                        {SpanAttributes.LLM_CONTENT_COMPLETION_CHUNK: "".join(content)},
-                    )
+                    set_event_completion_chunk(span, "".join(content))
 
                 # Assuming this is part of a generator, yield chunk or aggregated content
                 yield content
